# awsdeepracer_control
 This python package rewrite to support the new version Deepracer Console Software ```version 1.0.606.0```

# What's New
- Fix the video stream can not display
- Fix the `move` method add the new value to support new version web console
- Remove `move_forward`, `move_backward`, `turn_right`, `turn_left` method

# Package Repo Link
https://github.com/lshw54/awsdeepracer_control